import logging

from django.contrib.auth.forms import PasswordResetForm, PasswordChangeForm
from django.db.models import Q
from django.contrib.auth.models import User
from django import forms
from django.utils.translation import ugettext_lazy as _

from docbow.middleware import get_extra

logger = logging.getLogger('docbow')

class PasswordResetFormWithLogging(PasswordResetForm):
    email = forms.EmailField(widget=forms.HiddenInput(), required=False)
    identifier = forms.CharField(label=_('E-mail or identifier'), max_length=75)

    def clean_email(self):
        return None

    def clean_identifier(self):
        """
        Validates that an active user exists with the given email address.
        """
        identifier = self.cleaned_data["identifier"]
        self.users_cache = User.objects.filter(
                                Q(email__iexact=identifier)|Q(username=identifier),
                                is_active=True).distinct()
        if not len(self.users_cache):
            raise forms.ValidationError(_("That e-mail address or identifier doesn't have an associated user account. Are you sure you've registered?"))
        return identifier

    def save(self, *args, **kwargs):
        super(PasswordResetFormWithLogging, self).save(*args, **kwargs)
        emails = []
        for user in self.users_cache:
            emails.append('%s <%s>' % (user.username, user.email))
        if emails:
            logger.info('reset password mail sent to %s',
                    ', '.join(emails),
                    extra=get_extra())

class PasswordChangeFormWithLogging(PasswordChangeForm):
    def save(self, *args, **kwargs):
        super(PasswordChangeFormWithLogging, self).save(*args, **kwargs)
        logger.info('changed its password', extra=get_extra())

