import django.contrib.admin as admin

import models
from docbow_project.utils import filter_link, add_link
from ..docbow.models import DocbowUser
import docbow_project.actions as actions

cache = {}

class LogLineAdmin(admin.ModelAdmin):
    list_display = [ 'timestamp', 'levelname', 'ip2', 'user2', 'message' ]
    fields = [ 'timestamp', 'levelname', 'ip', 'user3', 'message']
    readonly_fields = fields
    list_filter = [ 'name', 'levelname', 'user' ]
    date_hierarchy = 'timestamp'
    actions = [ actions.export_as_csv ]
    search_fields = [ 'user', 'ip', 'message' ]

    class Media:
        css = {
                'all': ('log/css/logline.css',),
        }

    ip2 = filter_link('ip', 'Adresse IP')
    user2 = add_link('user', DocbowUser, 'username', filter_link('user', 'Utilisateur'))
    user3 = add_link('user', DocbowUser, 'username', metamodel=models.LogLine)


admin.site.register(models.LogLine, LogLineAdmin)
