import smtplib
import socket

from django.core.mail import EmailMultiAlternatives
from django.template.loader import render_to_string

from docbow.logger_adapter import get_logger

__ALL__ = ('notify', 'NotificationFailure')

class NotificationFailure(Exception):
    pass

def notify(request, mail_id, ctx={}, to=tuple(), cc=tuple(), reply_to=None, with_html=True):
    args = locals()
    logger = get_logger(request)
    subject_template = 'docbow/%s-subject.txt' % mail_id
    subject = render_to_string(subject_template, ctx).strip()
    body_template = 'docbow/%s-body.txt' % mail_id
    body = render_to_string(body_template, ctx)
    if not isinstance(to, (list,tuple)):
        to = (to,)
    if not isinstance(cc, (list,tuple)):
        cc = (cc,)
    headers = {}
    if reply_to:
        headers['Reply-To'] = reply_to
    email = EmailMultiAlternatives(to=to,
            headers=headers, subject=subject, body=body)
    if with_html:
        html_body_template = 'docbow/%s-body.html' % mail_id
        html_body = render_to_string(html_body_template, ctx)
        email.attach_alternative(html_body,
                mimetype='text/html')
    try:
        email.send(fail_silently=False)

    except (smtplib.SMTPException, socket.error), e:
        logger.exception('%s-notification failure %s' % (mail_id, args))
        raise NotificationFailure
