from django.core.urlresolvers import reverse

def filter_link(name, short_description):
    def f(self, obj):
        value = getattr(obj, name, None)
        return '<a href="?%s=%s">%s</a>' % (name, value, value)
    f.allow_tags = True
    f.short_description = short_description
    return f

__CACHE = {}

def add_link(name, model, attribute, g = None, metamodel=None):
    def f(self, obj):
        value = getattr(obj, name, None)
        if g:
            content = g(self, obj)
        else:
            content = value
        key = (model, attribute, value)
        if key not in __CACHE:
            value = getattr(obj, name, None)
            kwargs = { attribute: value }
            try:
                related_obj = model.objects.get(**kwargs)
                app_label = model._meta.app_label
                modelname = model.__name__.lower()
                url = reverse('docbow_admin:%s_%s_change' % (app_label,
                    modelname), args=(related_obj.id,))
            except model.DoesNotExist:
                url = ''
            __CACHE[key] = url
        else:
            url = __CACHE[key]
        if url:
            url = '<a href="%s" class="external-link"></a>' % url
        return content + url
    f.allow_tags = True
    if g:
        f.short_description = g.short_description
    else:
        f.short_description = metamodel._meta.get_field_by_name(name)[0].verbose_name
    return f

__SESSION_CACHE_NAME = '__function_session_cache__'
__CANARI = object()

def session_cache_decorator(func):
    '''Memoize result of pure function in the user session.

       It's useful to compute complex values only once per session.
    '''
    if func.__code__.co_argcount < 1 or 'request' != func.__code__.co_varnames[0]:
        raise ValueError('func is not a proper Django view, first argument must be named request')
    def f(request, *args, **kwargs):
        session_cache = request.session.setdefault(__SESSION_CACHE_NAME, {})
        v = session_cache.get(func, __CANARI)
        if v is __CANARI:
            v = session_cache[func] = func(request, *args, **kwargs)
        return v
    return f
